==> fop_1.0.dfsg2.orig.tar.gz: fop-1.0/test/java/org/apache/fop/config/UserConfigTestSuite.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: UserConfigTestSuite.java 772672 2009-05-07 15:08:30Z cbowditch $ */

package org.apache.fop.config;

import junit.framework.Test;
import junit.framework.TestSuite;

/**
 * Test suite for font configuration.
 */
public class UserConfigTestSuite {

    /**
     * Builds the test suite
     * @return the test suite
     */
    public static Test suite() {
        TestSuite suite = new TestSuite(
            "Basic functionality test suite for user configuration");
        //$JUnit-BEGIN$
        suite.addTest(new TestSuite(FontBaseBadTestCase.class));
        suite.addTest(new TestSuite(FontAttributesMissingTestCase.class));
        suite.addTest(new TestSuite(FontTripletAttributeMissingTestCase.class));
        suite.addTest(new TestSuite(FontMetricsUrlBadTestCase.class));
        suite.addTest(new TestSuite(FontEmbedUrlBadTestCase.class));
        suite.addTest(new TestSuite(FontMetricsUrlMalformedTestCase.class));
        suite.addTest(new TestSuite(FontEmbedUrlMalformedTestCase.class));
        suite.addTest(new TestSuite(FontsDirectoryRecursiveTestCase.class));
        suite.addTest(new TestSuite(FontsAutoDetectTestCase.class));
        suite.addTest(new TestSuite(FontsSubstitutionTestCase.class));
        suite.addTest(new TestSuite(FOURIResolverTestCase.class));
        //$JUnit-END$
        return suite;
    }

}

==> fop_1.1.dfsg.orig.tar.gz: fop-1.1/test/java/org/apache/fop/config/UserConfigTestSuite.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: UserConfigTestSuite.java 1198853 2011-11-07 18:18:29Z vhennebert $ */

package org.apache.fop.config;

import org.junit.runner.RunWith;
import org.junit.runners.Suite;
import org.junit.runners.Suite.SuiteClasses;

/**
 * Test suite for font configuration.
 */
@RunWith(Suite.class)
@SuiteClasses({
    FontBaseBadTestCase.class,
    FontAttributesMissingTestCase.class,
    FontTripletAttributeMissingTestCase.class,
    FontMetricsUrlBadTestCase.class,
    FontEmbedUrlBadTestCase.class,
    FontMetricsUrlMalformedTestCase.class,
    FontsDirectoryRecursiveTestCase.class,
    FontsAutoDetectTestCase.class,
    FontsSubstitutionTestCase.class,
    FOURIResolverTestCase.class
})
public class UserConfigTestSuite {
}
